# rsqlalchemy

[![Pytest](https://github.com/jzfqiu/rsqlalchemy/actions/workflows/test.yml/badge.svg)](https://github.com/jzfqiu/rsqlalchemy/actions/workflows/test.yml)

Converts rsql query into sqlalchemy expressions
